/* Sistemas Integrados TECNISA
   Compras e Suprimentos

Nome: 8986_CMPSTPO_EXCLUIR_PARTFILI

Descrio:
Excluso Automtica de Particularidades

P_TPRODUTO    - Todos os produtos
P_CDPRODINI   - Produto inicial
P_CDPRODFIN   - Produto final
P_CDFILIAL    - Filiais
P_CDMARCA     - Marcas
P_CDFORNECED  - Fornecedores
P_CDTIPPART   - Particularidades
P_CDGRUPFILI  - Grupo de filiais
*/

CREATE OR REPLACE
PROCEDURE EXCLUIR_PARTFILI (
    P_TPRODUTO     IN VARCHAR2,
    P_CDPRODINI    IN PRODUTO.CDARVPROD%TYPE,
    P_CDPRODFIN    IN PRODUTO.CDARVPROD%TYPE,
    P_CDFILIAL     IN VARCHAR2,
    P_CDMARCA      IN VARCHAR2,
    P_CDFORNECED   IN VARCHAR2,
    P_CDTIPPART    IN VARCHAR2,
    P_CDGRUPFILI   IN GRUPFILI.CDGRUPFILI%TYPE,
    P_CDOPERADOR   IN FILIOPER.CDOPERADOR%TYPE,
    P_CDFILIALORIG IN FILIAL.CDFILIAL%TYPE DEFAULT NULL,
    P_COMMIT IN VARCHAR2
    )
IS
   V_EMITENTE    VARCHAR2(4);
   V_TFILIAL     VARCHAR2(1);
   V_TCDMARCA    VARCHAR2(1);
   V_TCDFORNECED VARCHAR2(1);
   V_TCDFILIALORIG VARCHAR2(1);
   V_CDPRODFIN   VARCHAR2(30);
   V_CONT_COMMIT NUMBER := 0;
   V_QTDE_COMMIT NUMBER := 500;
BEGIN
   V_CDPRODFIN := P_CDPRODFIN||'ZZZZZZZZZZ';

   IF P_CDFILIAL IS NULL THEN
      V_TFILIAL := 'T';
   END IF;
   IF P_CDMARCA IS NULL THEN
      V_TCDMARCA := 'T';
   END IF;
   IF P_CDFORNECED IS NULL THEN
      V_TCDFORNECED := 'T';
   END IF;

   IF P_CDFILIALORIG IS NULL THEN
      V_TCDFILIALORIG := 'T';
   ELSE
      V_TCDFILIALORIG := '';
   END IF;

   FOR C_PARTFILI IN
      (SELECT
          PARTFILI.ROWID
       FROM
          PARTFILI, FILIAL
       WHERE (P_CDGRUPFILI IS NULL OR
              EXISTS(SELECT 1
                     FROM FILGRUPFILI
                     WHERE FILGRUPFILI.CDFILIAL   = PARTFILI.CDFILIAL
                       AND FILGRUPFILI.CDGRUPFILI = P_CDGRUPFILI)
              )
         AND ((INSTR(P_CDMARCA, PARTFILI.CDMARCA) > 0) OR V_TCDMARCA = 'T')
         AND ((INSTR(P_CDFORNECED, PARTFILI.CDFORNECED) > 0) OR V_TCDFORNECED = 'T')
         AND ((INSTR(P_CDFILIAL, PARTFILI.CDFILIAL) > 0) OR V_TFILIAL = 'T')
         AND ((INSTR(P_CDTIPPART, PARTFILI.CDTIPPART) > 0))
         AND PARTFILI.CDFILCOTA IS NULL
         AND PARTFILI.NRCOLEPRECO IS NULL
         AND ((PARTFILI.CDFILIAL <> P_CDFILIALORIG) OR (V_TCDFILIALORIG = 'T'))
         AND PARTFILI.CDFILIAL = FILIAL.CDFILIAL
         AND EXISTS (SELECT 1
                     FROM FILIOPER
                     WHERE FILIOPER.CDFILIAL = PARTFILI.CDFILIAL
                       AND FILIOPER.CDOPERADOR = P_CDOPERADOR)
         AND (P_TPRODUTO = 'T' OR
              EXISTS(SELECT 1
                     FROM PRODUTO
                     WHERE PRODUTO.CDPRODUTO = PARTFILI.CDPRODUTO
                       AND PRODUTO.CDARVPROD BETWEEN P_CDPRODINI AND V_CDPRODFIN)
              )
         AND NOT EXISTS (SELECT 1
                           FROM PARAMPRODSUP, FILIAL, FORNECEDOR, PARASUPRI
                          WHERE PARAMPRODSUP.CDPRODUTO = PARTFILI.CDPRODUTO
                            AND PARAMPRODSUP.CDFILIAL = PARTFILI.CDFILIAL
                            AND PARAMPRODSUP.CDFILIOPELOG = FILIAL.CDFILIAL
                            AND FILIAL.CDFORNOPELOG = FORNECEDOR.CDFORNECED
                            AND PARASUPRI.CDFILIAL = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)
                            AND PARASUPRI.IDUTILCONSSOLIOL = 'N'
                            AND PARTFILI.CDTIPPART = '4'))
   LOOP
      DELETE
      FROM PARTFILI
      WHERE PARTFILI.ROWID = C_PARTFILI.ROWID;
      IF P_COMMIT = 'S' THEN
         V_CONT_COMMIT := V_CONT_COMMIT + 1;
         IF (V_CONT_COMMIT >= V_QTDE_COMMIT) THEN
            V_CONT_COMMIT := 0;
            COMMIT;
         END IF;
      END IF;
   END LOOP;
   IF P_COMMIT = 'S' THEN
      COMMIT;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('EXCLUIR_PARTFILI','6.25.XXX'); END;
/
