CREATE OR REPLACE
PROCEDURE USR_EXPORTAREDZ_DENADAI IS
   V_DTGRV        DATE;
   V_HRGRV        VARCHAR2(04);

   V_FILIAL       VARCHAR(10);
   V_OUTROSR      FLOAT;
   V_IMPDEBT      FLOAT;
   V_WD_BAS7      FLOAT;
   V_WD_BAS12     FLOAT;
   V_WD_BAS18     FLOAT;
   V_WD_BAS25     FLOAT;
   V_WD_BAS32     FLOAT;
   V_WD_IDREDZ    INTEGER;

   V_NOVOCODIGO   INTEGER;
BEGIN
   V_DTGRV := NULL;
   V_HRGRV := NULL;

   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
        INTO V_DTGRV, V_HRGRV
        FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;

   FOR C_REDZEXPORT IN
      (SELECT R.CDFILIAL    , DTREDUCAOZ  , NRECFREDZ   , NRSERIEREDZ,
              NRREDREDZ   , VRGTREDZ    , NRPRIMCFREDZ, NRULTCFREDZ,
              VRTOTCANREDZ, VRVENLIQREDZ, VRVENBRUREDZ, VRTOTDESREDZ, VRSTRIBREDZ,
              VRISENCREDZ , VRNINCIDREDZ, VRISSREDZ   ,
              (LPAD(TO_NUMBER(NRREINIREDZ), 3, '0')) as NRREINIREDZ,
              CDCAIXA
         FROM REDUCAOZ R, (SELECT DISTINCT(CDFILIAL)
                             FROM FILGRUPFILI
                            WHERE USR_IDPROTHEUS = 'S') F
        WHERE NVL(USR_IDEXPORTA, 'S') = 'S'
          AND USR_DTEXPORTA IS NULL
          AND R.CDFILIAL = F.CDFILIAL
        ORDER BY R.CDFILIAL, DTREDUCAOZ, NRECFREDZ
       )
   LOOP
      V_OUTROSR  := 0;
      V_IMPDEBT  := 0;
      V_WD_BAS7  := 0;
      V_WD_BAS12 := 0;
      V_WD_BAS18 := 0;
      V_WD_BAS25 := 0;
      V_WD_BAS32 := 0;

      SELECT MAX(CDGRUPFILI)
        INTO V_FILIAL
        FROM FILGRUPFILI
       WHERE CDFILIAL = C_REDZEXPORT.CDFILIAL
         AND USR_IDPROTHEUS = 'S';


      IF NOT V_FILIAL IS NULL THEN
         SELECT SUM(VRACUTOTNFIS)
           INTO V_OUTROSR
           FROM TOTNFISCREDZ
          WHERE CDFILIAL   = C_REDZEXPORT.CDFILIAL
            AND DTREDUCAOZ = C_REDZEXPORT.DTREDUCAOZ
            AND NRECFREDZ  = C_REDZEXPORT.NRECFREDZ;

         SELECT SUM(VRIMPOSTORZ)
           INTO V_IMPDEBT
           FROM IMPOSTOREDZ
          WHERE CDFILIAL   = C_REDZEXPORT.CDFILIAL
            AND DTREDUCAOZ = C_REDZEXPORT.DTREDUCAOZ
            AND NRECFREDZ  = C_REDZEXPORT.NRECFREDZ;

         BEGIN
            SELECT VRBCALCIMPRZ
              INTO V_WD_BAS32
              FROM IMPOSTOREDZ
             WHERE CDFILIAL = C_REDZEXPORT.CDFILIAL
               AND CDCAIXA =  C_REDZEXPORT.CDCAIXA
               AND NRECFREDZ = C_REDZEXPORT.NRECFREDZ
               AND DTREDUCAOZ = C_REDZEXPORT.DTREDUCAOZ
               AND CDIMPOSTO =  '00'
               AND VRALIQIMPRZ = 3.2;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_WD_BAS32 := 0;
         END;

         BEGIN
            SELECT VRBCALCIMPRZ
              INTO V_WD_BAS7
              FROM IMPOSTOREDZ
             WHERE CDFILIAL = C_REDZEXPORT.CDFILIAL
               AND CDCAIXA =  C_REDZEXPORT.CDCAIXA
               AND NRECFREDZ = C_REDZEXPORT.NRECFREDZ
               AND DTREDUCAOZ = C_REDZEXPORT.DTREDUCAOZ
               AND CDIMPOSTO =  '00'
               AND VRALIQIMPRZ = 7;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_WD_BAS7 := 0;
         END;

         BEGIN
            SELECT VRBCALCIMPRZ
              INTO V_WD_BAS12
              FROM IMPOSTOREDZ
             WHERE CDFILIAL = C_REDZEXPORT.CDFILIAL
               AND CDCAIXA =  C_REDZEXPORT.CDCAIXA
               AND NRECFREDZ = C_REDZEXPORT.NRECFREDZ
               AND DTREDUCAOZ = C_REDZEXPORT.DTREDUCAOZ
               AND CDIMPOSTO =  '00'
               AND VRALIQIMPRZ = 12;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_WD_BAS12 := 0;
         END;

         BEGIN
            SELECT VRBCALCIMPRZ
              INTO V_WD_BAS18
              FROM IMPOSTOREDZ
             WHERE CDFILIAL = C_REDZEXPORT.CDFILIAL
               AND CDCAIXA =  C_REDZEXPORT.CDCAIXA
               AND NRECFREDZ = C_REDZEXPORT.NRECFREDZ
               AND DTREDUCAOZ = C_REDZEXPORT.DTREDUCAOZ
               AND CDIMPOSTO =  '00'
               AND VRALIQIMPRZ = 18;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_WD_BAS18 := 0;
         END;

         BEGIN
            SELECT VRBCALCIMPRZ
              INTO V_WD_BAS25
              FROM IMPOSTOREDZ
             WHERE CDFILIAL = C_REDZEXPORT.CDFILIAL
               AND CDCAIXA =  C_REDZEXPORT.CDCAIXA
               AND NRECFREDZ = C_REDZEXPORT.NRECFREDZ
               AND DTREDUCAOZ = C_REDZEXPORT.DTREDUCAOZ
               AND CDIMPOSTO =  '00'
               AND VRALIQIMPRZ = 25;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_WD_BAS25 := 0;
         END;

         /* Retorna o sequencial para a tabela */
         BEGIN
            SELECT WD_IDREDZ.NEXTVAL
              INTO V_NOVOCODIGO
              FROM DUAL;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_NOVOCODIGO := 1;
         END;

         SELECT NVL(MAX(WD_IDREDZ),0)
           INTO V_WD_IDREDZ
           FROM USR_ZWD
          WHERE CDFILIAL = C_REDZEXPORT.CDFILIAL
            AND CDCAIXA = C_REDZEXPORT.CDCAIXA
            AND NRECFREDZ = C_REDZEXPORT.NRECFREDZ
            AND DTREDUCAOZ = C_REDZEXPORT.DTREDUCAOZ
            AND WD_TPEDI = '1';

         IF V_WD_IDREDZ = 0 THEN
            INSERT INTO USR_ZWD
               (CDFILIAL, CDCAIXA, NRECFREDZ, DTREDUCAOZ,
                WD_IDREDZ, WD_EMPRESA, WD_FILIAL , WD_DTMOVTO,
                WD_PDV    ,
                WD_SERPDV ,
                WD_NUMREDZ,
                WD_GTFINAL,
                WD_NUMINI , WD_NUMFIM ,
                WD_CANCEL , WD_VALCON ,
                WD_DESC   , WD_SUBTRIB,
                WD_ISENTO , WD_NTRIB  ,
                WD_ISS    , WD_CRO    ,
                WD_COO    , WD_OUTROSR,
                WD_NUMERO , WD_GTINI  ,
                WD_IMPDEBT, WD_TPEDI,
                WD_BAS7, WD_BAS12, WD_BAS18, WD_BAS25, WD_BAS32,
                WD_DTGRV  , WD_HRGRV  , WD_DTIMP  , WD_HRIMP)
            VALUES
               (C_REDZEXPORT.CDFILIAL, C_REDZEXPORT.CDCAIXA, C_REDZEXPORT.NRECFREDZ, C_REDZEXPORT.DTREDUCAOZ,
                V_NOVOCODIGO, SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2),
                TO_DATE(C_REDZEXPORT.DTREDUCAOZ),
                C_REDZEXPORT.CDCAIXA||TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRECFREDZ, 10, ' '),4,7)) ,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRSERIEREDZ, 30, ' '),11,20)),
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRREDREDZ, 10, ' '),6,5)) ,
                C_REDZEXPORT.VRGTREDZ,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRPRIMCFREDZ, 10, ' '),5,10)) ,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRULTCFREDZ, 10, ' '),5,10)) ,
                C_REDZEXPORT.VRTOTCANREDZ, C_REDZEXPORT.VRVENLIQREDZ,
                C_REDZEXPORT.VRTOTDESREDZ, C_REDZEXPORT.VRSTRIBREDZ ,
                C_REDZEXPORT.VRISENCREDZ , C_REDZEXPORT.VRNINCIDREDZ,
                C_REDZEXPORT.VRISSREDZ   ,
                C_REDZEXPORT.NRREINIREDZ,   '000000',
                V_OUTROSR,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRREDREDZ, 10, ' '),5,10)) ,
                (C_REDZEXPORT.VRGTREDZ - C_REDZEXPORT.VRVENBRUREDZ),
                V_IMPDEBT, '1',
                V_WD_BAS7, V_WD_BAS12, V_WD_BAS18, V_WD_BAS25, V_WD_BAS32,
                V_DTGRV, V_HRGRV, NULL, '');
         ELSE
            INSERT INTO USR_ZWD
               (CDFILIAL, CDCAIXA, NRECFREDZ, DTREDUCAOZ,
                WD_IDREDZ, WD_EMPRESA, WD_FILIAL , WD_DTMOVTO,
                WD_PDV    ,
                WD_SERPDV ,
                WD_NUMREDZ,
                WD_GTFINAL,
                WD_NUMINI , WD_NUMFIM ,
                WD_CANCEL , WD_VALCON ,
                WD_DESC   , WD_SUBTRIB,
                WD_ISENTO , WD_NTRIB  ,
                WD_ISS    , WD_CRO    ,
                WD_COO    , WD_OUTROSR,
                WD_NUMERO , WD_GTINI  ,
                WD_IMPDEBT, WD_TPEDI,
                WD_BAS7, WD_BAS12, WD_BAS18, WD_BAS25, WD_BAS32,
                WD_DTGRV  , WD_HRGRV  , WD_DTIMP  , WD_HRIMP)
            VALUES
               (C_REDZEXPORT.CDFILIAL, C_REDZEXPORT.CDCAIXA, C_REDZEXPORT.NRECFREDZ, C_REDZEXPORT.DTREDUCAOZ,
                V_NOVOCODIGO, SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2),
                TO_DATE(C_REDZEXPORT.DTREDUCAOZ),
                C_REDZEXPORT.CDCAIXA||TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRECFREDZ, 10, ' '),4,7)) ,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRSERIEREDZ, 30, ' '),11,20)),
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRREDREDZ, 10, ' '),6,5)) ,
                C_REDZEXPORT.VRGTREDZ,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRPRIMCFREDZ, 10, ' '),5,10)) ,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRULTCFREDZ, 10, ' '),5,10)) ,
                C_REDZEXPORT.VRTOTCANREDZ, C_REDZEXPORT.VRVENLIQREDZ,
                C_REDZEXPORT.VRTOTDESREDZ, C_REDZEXPORT.VRSTRIBREDZ ,
                C_REDZEXPORT.VRISENCREDZ , C_REDZEXPORT.VRNINCIDREDZ,
                C_REDZEXPORT.VRISSREDZ   ,
                C_REDZEXPORT.NRREINIREDZ,   '000000',
                V_OUTROSR,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRREDREDZ, 10, ' '),5,10)) ,
                (C_REDZEXPORT.VRGTREDZ - C_REDZEXPORT.VRVENBRUREDZ),
                V_IMPDEBT, '2',
                V_WD_BAS7, V_WD_BAS12, V_WD_BAS18, V_WD_BAS25, V_WD_BAS32,
                V_DTGRV, V_HRGRV, NULL, '');

            /* Retorna o sequencial para a tabela */
            BEGIN
               SELECT WD_IDREDZ.NEXTVAL
                 INTO V_NOVOCODIGO
                 FROM DUAL;
            EXCEPTION
               WHEN NO_DATA_FOUND THEN
                  V_NOVOCODIGO := 1;
            END;

            INSERT INTO USR_ZWD
               (CDFILIAL, CDCAIXA, NRECFREDZ, DTREDUCAOZ,
                WD_IDREDZ, WD_EMPRESA, WD_FILIAL , WD_DTMOVTO,
                WD_PDV    ,
                WD_SERPDV ,
                WD_NUMREDZ,
                WD_GTFINAL,
                WD_NUMINI , WD_NUMFIM ,
                WD_CANCEL , WD_VALCON ,
                WD_DESC   , WD_SUBTRIB,
                WD_ISENTO , WD_NTRIB  ,
                WD_ISS    , WD_CRO    ,
                WD_COO    , WD_OUTROSR,
                WD_NUMERO , WD_GTINI  ,
                WD_IMPDEBT, WD_TPEDI,
                WD_BAS7, WD_BAS12, WD_BAS18, WD_BAS25, WD_BAS32,
                WD_DTGRV  , WD_HRGRV  , WD_DTIMP  , WD_HRIMP)
            VALUES
               (C_REDZEXPORT.CDFILIAL, C_REDZEXPORT.CDCAIXA, C_REDZEXPORT.NRECFREDZ, C_REDZEXPORT.DTREDUCAOZ,
                V_NOVOCODIGO, SUBSTR(V_FILIAL, 7, 2), SUBSTR(V_FILIAL, 9, 2),
                TO_DATE(C_REDZEXPORT.DTREDUCAOZ),
                C_REDZEXPORT.CDCAIXA||TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRECFREDZ, 10, ' '),4,7)) ,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRSERIEREDZ, 30, ' '),11,20)),
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRREDREDZ, 10, ' '),6,5)) ,
                C_REDZEXPORT.VRGTREDZ,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRPRIMCFREDZ, 10, ' '),5,10)) ,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRULTCFREDZ, 10, ' '),5,10)) ,
                C_REDZEXPORT.VRTOTCANREDZ, C_REDZEXPORT.VRVENLIQREDZ,
                C_REDZEXPORT.VRTOTDESREDZ, C_REDZEXPORT.VRSTRIBREDZ ,
                C_REDZEXPORT.VRISENCREDZ , C_REDZEXPORT.VRNINCIDREDZ,
                C_REDZEXPORT.VRISSREDZ   ,
                C_REDZEXPORT.NRREINIREDZ,   '000000',
                V_OUTROSR,
                TRIM(SUBSTR(LPAD(C_REDZEXPORT.NRREDREDZ, 10, ' '),5,10)) ,
                (C_REDZEXPORT.VRGTREDZ - C_REDZEXPORT.VRVENBRUREDZ),
                V_IMPDEBT, '1',
                V_WD_BAS7, V_WD_BAS12, V_WD_BAS18, V_WD_BAS25, V_WD_BAS32,
                V_DTGRV, V_HRGRV, NULL, '');
         END IF;

         UPDATE REDUCAOZ
            SET USR_IDEXPORTA = 'N',
                USR_DTEXPORTA = SYSDATE
          WHERE CDFILIAL = C_REDZEXPORT.CDFILIAL
            AND DTREDUCAOZ = C_REDZEXPORT.DTREDUCAOZ
            AND CDCAIXA = C_REDZEXPORT.CDCAIXA
            AND NRECFREDZ = C_REDZEXPORT.NRECFREDZ;
      END IF;
   END LOOP;
   COMMIT;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('USR_EXPORTAREDZ_DENADAI','5.09.000'); END;
/

